pydatajson
==========

Documentación de pydatajson: librería con funcionalidades para gestionar los metadatos de catálogos de datos abiertos que cumplan con el Perfil Nacional de Metadatos. Pydatajson es parte del `Paquete de Apertura de Datos <https://paquete-apertura-datos.readthedocs.io>`_.

Podés colaborar `cargando un nuevo issue <https://github.com/datosgobar/pydatajson/issues/new>`_, o `respondiendo a un issue ya existente <https://github.com/datosgobar/pydatajson/issues>`_. Lo mismo te invitamos a hacer en el `Paquete de Apertura de Datos <https://quete-apertura-datos.readthedocs.io>`_.

Indice
------

.. toctree::
   :maxdepth: 2

   README.md
   MANUAL.md

Documentación automática
------------------------

* :ref:`modindex`
* :ref:`genindex`

Versiones
---------

.. toctree::
   :maxdepth: 1

   HISTORY.md
